pub type CrateResult<T> = Result<T, Error>;

#[derive(Debug, thiserror::Error)]
pub enum Error {
    #[error(transparent)]
    ReqwestError(#[from] reqwest::Error),
    #[error(transparent)]
    SerdeJsonError(#[from] serde_json::Error),
    #[error(transparent)]
    ApiError(#[from] ApiError),
    #[error("Unexpected data from server {0}")]
    UnexpectedData(String)
}

#[derive(Debug, thiserror::Error)]
#[error("{0}")]
pub struct ApiError(pub String);

pub struct NoError();